Documentation
¶
Overview ¶
Package key contains the definition of the Key Provider, as well as various implementations of the concept.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Keys ¶
type Keys struct {
// Object Encryption Key used for sealing Objects.
KEK []byte `koanf:"kek"`
// Access Encryption Key used for sealing Access lists.
AEK []byte `koanf:"aek"`
// Token Encryption Key used for sealing Tokens.
TEK []byte `koanf:"tek"`
// Index Encryption Key used for searchable encryption.
IEK []byte `koanf:"iek"`
}
Keys contains the master key material used by D1. All keys must be 32 bytes.
Click to show internal directories.
Click to hide internal directories.